@@ -4,15 +4,15 @@ build_time_vars = {'ABIFLAGS': 'm',
  'AIX_GENUINE_CPLUSPLUS': 0,
  'AR': 'ar',
  'ARFLAGS': 'rc',
- 'ASDLGEN': 'python3.5 /builddir/build/BUILD/Python-3.5.1/Parser/asdl_c.py',
- 'ASDLGEN_FILES': '/builddir/build/BUILD/Python-3.5.1/Parser/asdl.py '
+ 'ASDLGEN': 'python3.5 /builddir/build/BUILD/Python-3.5.2/Parser/asdl_c.py',
+ 'ASDLGEN_FILES': '/builddir/build/BUILD/Python-3.5.2/Parser/asdl.py '
                   '/Parser/asdl_c.py',
- 'AST_ASDL': '/builddir/build/BUILD/Python-3.5.1/Parser/Python.asdl',
+ 'AST_ASDL': '/builddir/build/BUILD/Python-3.5.2/Parser/Python.asdl',
  'AST_C': 'Python/Python-ast.c',
  'AST_C_DIR': 'Python',
  'AST_H': 'Include/Python-ast.h',
  'AST_H_DIR': 'Include',
- 'BASECFLAGS': '-Wno-unused-result -Wsign-compare -Wunreachable-code',
+ 'BASECFLAGS': '-Wno-unused-result -Wsign-compare',
  'BASECPPFLAGS': '',
  'BASEMODLIBS': '',
  'BINDIR': '/usr/bin',
@@ -26,11 +26,10 @@ build_time_vars = {'ABIFLAGS': 'm',
  'BYTESTR_DEPS': '\\',
  'CC': 'gcc -pthread',
  'CCSHARED': '-fPIC',
- 'CFLAGS': '-Wno-unused-result -Wsign-compare -Wunreachable-code '
-           '-DDYNAMIC_ANNOTATIONS_ENABLED=1 -DNDEBUG -O2 -g -pipe -Wall '
-           '-Werror=format-security -Wp,-D_FORTIFY_SOURCE=2 -fexceptions '
-           '-fstack-protector-strong --param=ssp-buffer-size=4 '
-           '-grecord-gcc-switches '
+ 'CFLAGS': '-Wno-unused-result -Wsign-compare -DDYNAMIC_ANNOTATIONS_ENABLED=1 '
+           '-DNDEBUG -O2 -g -pipe -Wall -Werror=format-security '
+           '-Wp,-D_FORTIFY_SOURCE=2 -fexceptions -fstack-protector-strong '
+           '--param=ssp-buffer-size=4 -grecord-gcc-switches '
            '-specs=/usr/lib/rpm/redhat/redhat-hardened-cc1 -m64 -D_GNU_SOURCE '
            '-fPIC -fwrapv',
  'CFLAGSFORSHARED': '-fPIC',
@@ -72,11 +71,11 @@ build_time_vars = {'ABIFLAGS': 'm',
  'CONFINCLUDEDIR': '/usr/include',
  'CONFINCLUDEPY': '/usr/include/python3.5m',
  'COREPYTHONPATH': ':plat-linux',
- 'COVERAGE_INFO': '/builddir/build/BUILD/Python-3.5.1/build/optimized/coverage.info',
- 'COVERAGE_REPORT': '/builddir/build/BUILD/Python-3.5.1/build/optimized/lcov-report',
+ 'COVERAGE_INFO': '/builddir/build/BUILD/Python-3.5.2/build/optimized/coverage.info',
+ 'COVERAGE_REPORT': '/builddir/build/BUILD/Python-3.5.2/build/optimized/lcov-report',
  'COVERAGE_REPORT_OPTIONS': '--no-branch-coverage --title "CPython lcov '
                             'report"',
- 'CPPFLAGS': '-I. -IInclude -I/builddir/build/BUILD/Python-3.5.1/Include',
+ 'CPPFLAGS': '-I. -IInclude -I/builddir/build/BUILD/Python-3.5.2/Include',
  'CXX': 'g++ -pthread',
  'DESTDIRS': '/usr /usr/lib64 /usr/lib64/python3.5 '
              '/usr/lib64/python3.5/lib-dynload',
@@ -109,7 +108,7 @@ build_time_vars = {'ABIFLAGS': 'm',
  'GNULD': 'yes',
  'GRAMMAR_C': 'Python/graminit.c',
  'GRAMMAR_H': 'Include/graminit.h',
- 'GRAMMAR_INPUT': '/builddir/build/BUILD/Python-3.5.1/Grammar/Grammar',
+ 'GRAMMAR_INPUT': '/builddir/build/BUILD/Python-3.5.2/Grammar/Grammar',
  'HAVE_ACCEPT4': 1,
  'HAVE_ACOSH': 1,
  'HAVE_ADDRINFO': 1,
@@ -228,7 +227,7 @@ build_time_vars = {'ABIFLAGS': 'm',
  'HAVE_GETPRIORITY': 1,
  'HAVE_GETPWENT': 1,
  'HAVE_GETRANDOM': 0,
- 'HAVE_GETRANDOM_SYSCALL': 0,
+ 'HAVE_GETRANDOM_SYSCALL': 1,
  'HAVE_GETRESGID': 1,
  'HAVE_GETRESUID': 1,
  'HAVE_GETSID': 1,
@@ -275,6 +274,7 @@ build_time_vars = {'ABIFLAGS': 'm',
  'HAVE_LINUX_CAN_RAW_FD_FRAMES': 1,
  'HAVE_LINUX_CAN_RAW_H': 1,
  'HAVE_LINUX_NETLINK_H': 1,
+ 'HAVE_LINUX_RANDOM_H': 1,
  'HAVE_LINUX_TIPC_H': 1,
  'HAVE_LOCKF': 1,
  'HAVE_LOG1P': 1,
@@ -339,6 +339,7 @@ build_time_vars = {'ABIFLAGS': 'm',
  'HAVE_RL_COMPLETION_MATCHES': 1,
  'HAVE_RL_COMPLETION_SUPPRESS_APPEND': 1,
  'HAVE_RL_PRE_INPUT_HOOK': 1,
+ 'HAVE_RL_RESIZE_TERMINAL': 1,
  'HAVE_ROUND': 1,
  'HAVE_SCHED_GET_PRIORITY_MAX': 1,
  'HAVE_SCHED_H': 1,
@@ -405,7 +406,6 @@ build_time_vars = {'ABIFLAGS': 'm',
  'HAVE_STRUCT_STAT_ST_GEN': 0,
  'HAVE_STRUCT_STAT_ST_RDEV': 1,
  'HAVE_STRUCT_TM_TM_ZONE': 1,
- 'HAVE_ST_BLOCKS': 1,
  'HAVE_SYMLINK': 1,
  'HAVE_SYMLINKAT': 1,
  'HAVE_SYNC': 1,
@@ -540,7 +540,7 @@ build_time_vars = {'ABIFLAGS': 'm',
  'MAINCC': 'gcc -pthread',
  'MAJOR_IN_MKDEV': 0,
  'MAJOR_IN_SYSMACROS': 0,
- 'MAKESETUP': '/builddir/build/BUILD/Python-3.5.1/Modules/makesetup',
+ 'MAKESETUP': '/builddir/build/BUILD/Python-3.5.2/Modules/makesetup',
  'MANDIR': '/usr/share/man',
  'MKDIR_P': '/usr/bin/mkdir -p',
  'MODLIBS': '',
@@ -564,13 +564,13 @@ build_time_vars = {'ABIFLAGS': 'm',
  'OPCODETARGETGEN': '\\',
  'OPCODETARGETGEN_FILES': '\\',
  'OPCODETARGETS_H': '\\',
- 'OPCODE_H': '/builddir/build/BUILD/Python-3.5.1/Include/opcode.h',
- 'OPCODE_H_DIR': '/builddir/build/BUILD/Python-3.5.1/Include',
+ 'OPCODE_H': '/builddir/build/BUILD/Python-3.5.2/Include/opcode.h',
+ 'OPCODE_H_DIR': '/builddir/build/BUILD/Python-3.5.2/Include',
  'OPCODE_H_GEN': 'python3.5  '
-                 '/builddir/build/BUILD/Python-3.5.1/Tools/scripts/generate_opcode_h.py '
+                 '/builddir/build/BUILD/Python-3.5.2/Tools/scripts/generate_opcode_h.py '
                  '/Lib/opcode.py '
-                 '/builddir/build/BUILD/Python-3.5.1/Include/opcode.h',
- 'OPCODE_H_SCRIPT': '/builddir/build/BUILD/Python-3.5.1/Tools/scripts/generate_opcode_h.py',
+                 '/builddir/build/BUILD/Python-3.5.2/Include/opcode.h',
+ 'OPCODE_H_SCRIPT': '/builddir/build/BUILD/Python-3.5.2/Tools/scripts/generate_opcode_h.py',
  'OPT': '-DDYNAMIC_ANNOTATIONS_ENABLED=1 -DNDEBUG -O2 -g -pipe -Wall '
         '-Werror=format-security -Wp,-D_FORTIFY_SOURCE=2 -fexceptions '
         '-fstack-protector-strong --param=ssp-buffer-size=4 '
@@ -595,7 +595,10 @@ build_time_vars = {'ABIFLAGS': 'm',
  'PLATDIR': 'plat-linux',
  'POBJS': '\\',
  'POSIX_SEMAPHORES_NOT_ENABLED': 0,
- 'PROFILE_TASK': '-m test.regrtest --pgo',
+ 'PROFILE_TASK': '-m test.regrtest --pgo -x test_asyncore test_gdb '
+                 'test_multiprocessing_fork test_multiprocessing_forkserver '
+                 'test_multiprocessing_main_handling '
+                 'test_multiprocessing_spawn test_subprocess',
  'PSRCS': '\\',
  'PTHREAD_SYSTEM_SCHED_SUPPORTED': 1,
  'PY3LIBRARY': 'libpython3.so',
@@ -609,7 +612,7 @@ build_time_vars = {'ABIFLAGS': 'm',
  'PYTHON_FOR_BUILD': './python -E',
  'PYTHON_HEADERS': '\\',
  'PYTHON_OBJS': '\\',
- 'PY_CFLAGS': '-Wno-unused-result -Wsign-compare -Wunreachable-code '
+ 'PY_CFLAGS': '-Wno-unused-result -Wsign-compare '
               '-DDYNAMIC_ANNOTATIONS_ENABLED=1 -DNDEBUG -O2 -g -pipe -Wall '
               '-Werror=format-security -Wp,-D_FORTIFY_SOURCE=2 -fexceptions '
               '-fstack-protector-strong --param=ssp-buffer-size=4 '
@@ -617,7 +620,7 @@ build_time_vars = {'ABIFLAGS': 'm',
               '-specs=/usr/lib/rpm/redhat/redhat-hardened-cc1 -m64 '
               '-D_GNU_SOURCE -fPIC -fwrapv',
  'PY_CFLAGS_NODIST': '-Werror=declaration-after-statement',
- 'PY_CORE_CFLAGS': '-Wno-unused-result -Wsign-compare -Wunreachable-code '
+ 'PY_CORE_CFLAGS': '-Wno-unused-result -Wsign-compare '
                    '-DDYNAMIC_ANNOTATIONS_ENABLED=1 -DNDEBUG -O2 -g -pipe '
                    '-Wall -Werror=format-security -Wp,-D_FORTIFY_SOURCE=2 '
                    '-fexceptions -fstack-protector-strong '
@@ -625,9 +628,9 @@ build_time_vars = {'ABIFLAGS': 'm',
                    '-specs=/usr/lib/rpm/redhat/redhat-hardened-cc1 -m64 '
                    '-D_GNU_SOURCE -fPIC -fwrapv '
                    '-Werror=declaration-after-statement -I. -IInclude '
-                   '-I/builddir/build/BUILD/Python-3.5.1/Include  '
+                   '-I/builddir/build/BUILD/Python-3.5.2/Include  '
                    '-DPy_BUILD_CORE',
- 'PY_CPPFLAGS': '-I. -IInclude -I/builddir/build/BUILD/Python-3.5.1/Include',
+ 'PY_CPPFLAGS': '-I. -IInclude -I/builddir/build/BUILD/Python-3.5.2/Include',
  'PY_FORMAT_LONG_LONG': '"ll"',
  'PY_FORMAT_SIZE_T': '"z"',
  'PY_LDFLAGS': '-Wl,-z,relro -specs=/usr/lib/rpm/redhat/redhat-hardened-ld',
@@ -639,7 +642,7 @@ build_time_vars = {'ABIFLAGS': 'm',
  'READELF': 'readelf',
  'RESSRCDIR': 'Mac/Resources/framework',
  'RETSIGTYPE': 'void',
- 'RUNSHARED': 'LD_LIBRARY_PATH=/builddir/build/BUILD/Python-3.5.1/build/optimized',
+ 'RUNSHARED': 'LD_LIBRARY_PATH=/builddir/build/BUILD/Python-3.5.2/build/optimized',
  'SCRIPTDIR': '/usr/lib64',
  'SETPGRP_HAVE_ARG': 0,
  'SGI_ABI': '',
@@ -668,7 +671,7 @@ build_time_vars = {'ABIFLAGS': 'm',
  'SIZEOF__BOOL': 1,
  'SOABI': 'cpython-35m-ppc64-linux-gnu',
  'SRCDIRS': 'Parser Grammar Objects Python Modules Mac Programs',
- 'SRC_GDB_HOOKS': '/builddir/build/BUILD/Python-3.5.1/Tools/gdb/libpython.py',
+ 'SRC_GDB_HOOKS': '/builddir/build/BUILD/Python-3.5.2/Tools/gdb/libpython.py',
  'STDC_HEADERS': 1,
  'STRICT_SYSV_CURSES': "/* Don't use ncurses extensions */",
  'STRIPFLAG': '-s',
@@ -681,10 +684,10 @@ build_time_vars = {'ABIFLAGS': 'm',
  'TCLTK_LIBS': '',
  'TESTOPTS': '',
  'TESTPATH': '',
- 'TESTPYTHON': 'LD_LIBRARY_PATH=/builddir/build/BUILD/Python-3.5.1/build/optimized '
+ 'TESTPYTHON': 'LD_LIBRARY_PATH=/builddir/build/BUILD/Python-3.5.2/build/optimized '
                './python',
  'TESTPYTHONOPTS': '',
- 'TESTRUNNER': 'LD_LIBRARY_PATH=/builddir/build/BUILD/Python-3.5.1/build/optimized '
+ 'TESTRUNNER': 'LD_LIBRARY_PATH=/builddir/build/BUILD/Python-3.5.2/build/optimized '
                './python /Tools/scripts/run_tests.py',
  'TESTTIMEOUT': 3600,
  'THREADOBJ': 'Python/thread.o',
@@ -697,7 +700,7 @@ build_time_vars = {'ABIFLAGS': 'm',
  'USE_INLINE': 1,
  'VA_LIST_IS_ARRAY': 0,
  'VERSION': '3.5',
- 'VPATH': '/builddir/build/BUILD/Python-3.5.1',
+ 'VPATH': '/builddir/build/BUILD/Python-3.5.2',
  'WANT_SIGFPE_HANDLER': 0,
  'WINDOW_HAS_FLAGS': 1,
  'WITH_DOC_STRINGS': 1,
@@ -711,9 +714,10 @@ build_time_vars = {'ABIFLAGS': 'm',
  'WITH_VALGRIND': 1,
  'X87_DOUBLE_ROUNDING': 0,
  'XMLLIBSUBDIRS': 'xml xml/dom xml/etree xml/parsers xml/sax',
- 'abs_builddir': '/builddir/build/BUILD/Python-3.5.1/build/optimized',
- 'abs_srcdir': '/builddir/build/BUILD/Python-3.5.1',
+ 'abs_builddir': '/builddir/build/BUILD/Python-3.5.2/build/optimized',
+ 'abs_srcdir': '/builddir/build/BUILD/Python-3.5.2',
+ 'cross_compiling': 'no',
  'datarootdir': '/usr/share',
  'exec_prefix': '/usr',
  'prefix': '/usr',
- 'srcdir': '/builddir/build/BUILD/Python-3.5.1'}
+ 'srcdir': '/builddir/build/BUILD/Python-3.5.2'}
