@@ -150,27 +150,6 @@ def _skipInRpmBuild(reason):
     else:
         return _id
 
-def _expectedFailureInRpmBuild(func):
-    """
-    Non-standard/downstream-only decorator for marking a specific unit test
-    as expected to fail within the %check of an rpmbuild.
-
-    Specifically, this takes effect when WITHIN_PYTHON_RPM_BUILD is set within
-    the environment, and has no effect otherwise.
-    """
-    @functools.wraps(func)
-    def wrapper(*args, **kwargs):
-        if 'WITHIN_PYTHON_RPM_BUILD' in os.environ:
-            try:
-                func(*args, **kwargs)
-            except Exception:
-                raise _ExpectedFailure(sys.exc_info())
-            raise _UnexpectedSuccess
-        else:
-            # Call directly:
-            func(*args, **kwargs)
-    return wrapper
-
 class _AssertRaisesBaseContext(_BaseTestCaseContext):
 
     def __init__(self, expected, test_case, expected_regex=None):
@@ -1002,7 +981,7 @@ class TestCase(object):
 
                 if item1 != item2:
                     differing += ('\nFirst differing element %d:\n%s\n%s\n' %
-                                 (i, item1, item2))
+                                 ((i,) + _common_shorten_repr(item1, item2)))
                     break
             else:
                 if (len1 == len2 and seq_type is None and
@@ -1015,7 +994,7 @@ class TestCase(object):
                              'elements.\n' % (seq_type_name, len1 - len2))
                 try:
                     differing += ('First extra element %d:\n%s\n' %
-                                  (len2, seq1[len2]))
+                                  (len2, safe_repr(seq1[len2])))
                 except (TypeError, IndexError, NotImplementedError):
                     differing += ('Unable to index element %d '
                                   'of first %s\n' % (len2, seq_type_name))
@@ -1024,7 +1003,7 @@ class TestCase(object):
                              'elements.\n' % (seq_type_name, len2 - len1))
                 try:
                     differing += ('First extra element %d:\n%s\n' %
-                                  (len1, seq2[len1]))
+                                  (len1, safe_repr(seq2[len1])))
                 except (TypeError, IndexError, NotImplementedError):
                     differing += ('Unable to index element %d '
                                   'of second %s\n' % (len1, seq_type_name))
